==> illumination_0.1.20090520-1.tar.gz: illumination-0.1.20090520/include/Lum/OS/Hildon/KeyboardManager.h <==
#ifndef LUM_OS_HILDON_KEYBOARDMANAGER_H
#define LUM_OS_HILDON_KEYBOARDMANAGER_H

/*
  This source is part of the Illumination library
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <X11/Xlib.h>

#include <Lum/OS/Manager/KeyboardManager.h>

namespace Lum {
  namespace OS {
    namespace Hildon {

      class LUMAPI KeyboardManager : public Manager::KeyboardManager
      {
      private:
        OS::Window  *window;
        Lum::Object *object;

      private:
        ::Window GetKeyboardWindow() const;
        void ShowKeyboard();
        void HideKeyboard();

      public:
        KeyboardManager();
        ~KeyboardManager();

        void Shutdown();

        void OnWindowFocusIn(OS::Window* window);
        void OnWindowFocusOut(OS::Window* window);
        void OnFocusChange(OS::Window* window, Lum::Object* oldObject, Lum::Object* newObject);

        bool HandleEvent(OS::Window* window, OS::Event* event);

        void Cut();
        void Copy();
        void Paste();
      };
    }
  }
}

#endif

==> illumination_0.1.20100201-1.tar.gz: illumination-0.1.20100201/include/Lum/OS/Hildon/KeyboardManager.h <==
#ifndef LUM_OS_HILDON_KEYBOARDMANAGER_H
#define LUM_OS_HILDON_KEYBOARDMANAGER_H

/*
  This source is part of the Illumination library
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <X11/Xlib.h>

#include <Lum/OS/Manager/KeyboardManager.h>

#include <hildon-input-method/hildon-im-protocol.h>

namespace Lum {
  namespace OS {
    namespace Hildon {

      class LUMAPI KeyboardManager : public Manager::KeyboardManager
      {
      private:
        OS::Window      *window;
        Lum::Object     *object;
        std::string     buffer;
        HildonIMTrigger triggerType;

      private:
        ::Window GetKeyboardWindow() const;
        void SendClipboardSelectionQueryResponse();
        void SendSurrounding();
        void SendKey(Key key);
        void ShowKeyboard();
        void HideKeyboard();

      public:
        KeyboardManager();
        ~KeyboardManager();

        void Shutdown();

        void OnWindowFocusIn(OS::Window* window);
        void OnWindowFocusOut(OS::Window* window);
        void OnFocusChange(OS::Window* window,
                           Lum::Object* oldObject,
                           Lum::Object* newObject);
        void OnMouseClick(Window* window,
                          Lum::Object* object,
                          MouseEvent* event);

        bool HandleEvent(Window* window, Event* event);

        void Cut();
        void Copy();
        void Paste();
      };
    }
  }
}

#endif
